/**
 * 爬虫错误类
 * @extends Error
 */
class CrawlerError extends Error {
  /**
   * @param {string} message - 错误信息
   * @param {string} code - 错误代码
   * @param {string} platform - 平台名称
   * @param {Error} [originalError] - 原始错误对象
   */
  constructor(message, code, platform, originalError = null) {
    super(message);
    this.name = 'CrawlerError';
    this.code = code;
    this.platform = platform;
    this.originalError = originalError;
    this.timestamp = new Date().toISOString();
  }

  /**
   * 转换为JSON对象
   * @returns {Object} 错误信息对象
   */
  toJSON() {
    return {
      name: this.name,
      message: this.message,
      code: this.code,
      platform: this.platform,
      timestamp: this.timestamp,
      stack: this.stack,
      originalError: this.originalError ? {
        message: this.originalError.message,
        stack: this.originalError.stack
      } : null
    };
  }
}

module.exports = CrawlerError; 